@@ -4,13 +4,13 @@
  *	Created by:	Robert French
  *
  *	$Source: /cvsroot/gaim/gaim/src/protocols/zephyr/ZSendPkt.c,v $
- *	$Author: warmenhoven $
+ *	$Author: thekingant $
  *
  *	Copyright (c) 1987,1991 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
  *	"mit-copyright.h". 
  */
-/* $Header: /cvsroot/gaim/gaim/src/protocols/zephyr/ZSendPkt.c,v 1.2 2001/10/03 19:38:28 warmenhoven Exp $ */
+/* $Header: /cvsroot/gaim/gaim/src/protocols/zephyr/ZSendPkt.c,v 1.3 2003/11/11 07:08:13 thekingant Exp $ */
 
 #ifndef lint
 static char rcsid_ZSendPacket_c[] =
@@ -38,7 +38,7 @@ Code_t ZSendPacket(packet, len, waitforack)
 	return (ZERR_PKTLEN);
     
     if (ZGetFD() < 0)
-	if ((retval = ZOpenPort((u_short *)0)) != ZERR_NONE)
+	if ((retval = ZOpenPort((unsigned short *)0)) != ZERR_NONE)
 	    return (retval);
 
     dest = ZGetDestAddr();
